@@ -1,4 +1,5 @@
-import io
+import os
+import tempfile
 from concurrent.futures import ThreadPoolExecutor
 
 from .code_source import CodeSource
@@ -175,17 +176,17 @@ class FeatureGroupVersion(AbstractApiClass):
         return self.describe().status
 
     # internal call
-    def _get_avro_file(self, file_part):
-        file = io.BytesIO()
+    def _download_avro_file(self, file_part, tmp_dir):
         offset = 0
-        while True:
-            with self.client._call_api('_downloadFeatureGroupVersionPartChunk', 'GET', query_params={'featureGroupVersion': self.id, 'part': file_part, 'offset': offset}, streamable_response=True) as chunk:
-                bytes_written = file.write(chunk.read())
-            if not bytes_written:
-                break
-            offset += bytes_written
-        file.seek(0)
-        return file
+        part_path = os.path.join(tmp_dir, f'{file_part}.avro')
+        with open(part_path, 'wb') as file:
+            while True:
+                with self.client._call_api('_downloadFeatureGroupVersionPartChunk', 'GET', query_params={'featureGroupVersion': self.id, 'part': file_part, 'offset': offset}, streamable_response=True) as chunk:
+                    bytes_written = file.write(chunk.read())
+                if not bytes_written:
+                    break
+                offset += bytes_written
+        return part_path
 
     def load_as_pandas(self, max_workers=10):
         """
@@ -204,14 +205,16 @@ class FeatureGroupVersion(AbstractApiClass):
             '_getFeatureGroupVersionPartCount', 'GET', query_params={'featureGroupVersion': self.id}))
         data_df = pd.DataFrame()
         with ThreadPoolExecutor(max_workers=max_workers) as executor:
-            file_futures = [executor.submit(
-                self._get_avro_file, file_part) for file_part in file_parts]
-            for future in file_futures:
-                data = future.result()
-                reader = fastavro.reader(data)
-                data_df = data_df.append(
-                    pd.DataFrame.from_records([r for r in reader]))
-                for col in data_df.columns:
-                    if pd.core.dtypes.common.is_datetime64_ns_dtype(data_df[col]):
-                        data_df[col] = data_df[col].dt.tz_localize(None)
+            with tempfile.TemporaryDirectory() as tmp_dir:
+                file_futures = [executor.submit(
+                    self._download_avro_file, file_part, tmp_dir) for file_part in file_parts]
+                for future in file_futures:
+                    part_path = future.result()
+                    with open(part_path, 'rb') as part_data:
+                        reader = fastavro.reader(part_data)
+                        data_df = pd.concat(
+                            [data_df, pd.DataFrame([r for r in reader])])
+            for col in data_df.columns:
+                if pd.core.dtypes.common.is_datetime64_ns_dtype(data_df[col]):
+                    data_df[col] = data_df[col].dt.tz_localize(None)
         return data_df
