@@ -70,6 +70,19 @@ class ModelVersion(AbstractApiClass):
         """
         return self.client.delete_model_version(self.model_version)
 
+    def export_model_artifact_as_feature_group(self, table_name: str, artifact_type: str):
+        """
+        Exports metric artifact data for a model as a feature group.
+
+        Args:
+            table_name (str): The name of the feature group table to create.
+            artifact_type (str): An EvalArtifact enum of which artifact to export.
+
+        Returns:
+            FeatureGroup: The created feature group.
+        """
+        return self.client.export_model_artifact_as_feature_group(self.model_version, table_name, artifact_type)
+
     def refresh(self):
         """
         Calls describe and refreshes the current object's fields
@@ -92,6 +105,18 @@ class ModelVersion(AbstractApiClass):
         """
         return self.client.describe_model_version(self.model_version)
 
+    def get_training_data_logs(self):
+        """
+        Retrieves the data preparation logs during model training.
+
+        Args:
+            model_version (str): The unique version ID of the model version
+
+        Returns:
+            DataPrepLogs: A list of logs.
+        """
+        return self.client.get_training_data_logs(self.model_version)
+
     def get_training_logs(self, stdout: bool = False, stderr: bool = False):
         """
         Returns training logs for the model.
